@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Xm.h.in,v 1.9 1999/11/04 11:43:44 danny Exp $
+ * $Id: Xm.h.in,v 1.11 2000/08/29 15:12:51 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,14 +24,15 @@
  **/
 
 
-#ifndef XM_H
-#define XM_H
+#ifndef _XM_H
+#define _XM_H
 
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
 #include <X11/Xatom.h>
 #include <Xm/XmStrDefs.h>
 #include <Xm/VendorS.h>
+#include <Xm/VirtKeys.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -47,10 +49,10 @@ extern "C" {
 /* Version Information */
 
 #define LESSTIF_VERSION 0
-#define LESSTIF_REVISION 89
+#define LESSTIF_REVISION 91
 
 #define LesstifVersion (LESSTIF_VERSION * 1000 + LESSTIF_REVISION)
-#define LesstifVERSION_STRING "@(#)GNU/LessTif Version 1.2 Release 0.89.9"
+#define LesstifVERSION_STRING "@(#)GNU/LessTif Version 1.2 Release 0.91.8"
 
 /* since we're replacing Motif 1.2... */
 #define XmVERSION 1
@@ -1057,5 +1059,4 @@ extern void XmImVaSetValues(Widget w, ...);
 }
 #endif
 
-#endif /* XM_H */
-
+#endif /* _XM_H */
